@@ -77,6 +77,8 @@ DataBackendDataTable = R6Class("DataBackendDataTable", inherit = DataBackend,
     #'
     #' @param n (`integer(1)`)\cr
     #'   Number of rows.
+    #'
+    #' @return [data.table::data.table()] of the first `n` rows.
     head = function(n = 6L) {
       head(private$.data, n)
     },
@@ -86,6 +88,8 @@ DataBackendDataTable = R6Class("DataBackendDataTable", inherit = DataBackend,
     #' specified. If `na_rm` is `TRUE`, missing values are removed from the
     #' returned vectors of distinct values. Non-existing rows and columns are
     #' silently ignored.
+    #'
+    #' @return Named `list()` of distinct values.
     distinct = function(rows, cols, na_rm = TRUE) {
       cols = intersect(cols, colnames(private$.data))
       if (is.null(rows)) {
@@ -98,6 +102,8 @@ DataBackendDataTable = R6Class("DataBackendDataTable", inherit = DataBackend,
     #' @description
     #' Returns the number of missing values per column in the specified slice
     #' of data. Non-existing rows and columns are silently ignored.
+    #'
+    #' @return Total of missing values per column (named `numeric()`).
     missings = function(rows, cols) {
       data = self$data(rows, cols)
       map_int(data, function(x) sum(is.na(x)))
@@ -140,17 +146,17 @@ DataBackendDataTable = R6Class("DataBackendDataTable", inherit = DataBackend,
 #' @param data ([data.frame()])\cr
 #'   The input [data.frame()].
 #'   Converted to a [data.table::data.table()] automatically.
-#' @template param_primary_key
+#'
 #' @param keep_rownames (`logical(1)` | `character(1)`)\cr
 #'   If `TRUE` or a single string, keeps the row names of `data` as a new column.
 #'   The column is named like the provided string, defaulting to `"..rownames"` for `keep_rownames == TRUE`.
 #'   Note that the created column will be used as a regular feature by the task unless you manually change the column role.
 #'   Also see [data.table::as.data.table()].
+#'
 #' @rdname as_data_backend
 #' @export
 as_data_backend.data.frame = function(data, primary_key = NULL, keep_rownames = FALSE, ...) {
   assert_data_frame(data, min.cols = 1L, col.names = "unique")
-
   if (!isFALSE(keep_rownames)) {
     if (isTRUE(keep_rownames)) {
       keep_rownames = "..rownames"
@@ -160,17 +166,28 @@ as_data_backend.data.frame = function(data, primary_key = NULL, keep_rownames =
   }
 
   data = as.data.table(data, keep.rownames = keep_rownames)
+  compact_seq = FALSE
 
-  if (!is.null(primary_key)) {
+  if (is.character(primary_key)) {
     assert_string(primary_key)
     assert_choice(primary_key, colnames(data))
     assert_integer(data[[primary_key]], any.missing = FALSE, unique = TRUE)
-    b = DataBackendDataTable$new(data, primary_key)
   } else {
-    data = insert_named(as.data.table(data), list("..row_id" = seq_row(data)))
-    b = DataBackendDataTable$new(data, primary_key = "..row_id")
-    b$compact_seq = TRUE
+    if (is.null(primary_key)) {
+      row_ids = seq_row(data)
+      compact_seq = TRUE
+    } else if (is.integer(primary_key)) {
+      row_ids = assert_integer(primary_key, len = nrow(data), any.missing = FALSE, unique = TRUE)
+    } else {
+      stopf("Argument 'primary_key' must be NULL, a column name or a vector of ids")
+    }
+
+    primary_key = "..row_id"
+    data = insert_named(data, list("..row_id" = row_ids))
   }
 
+  b = DataBackendDataTable$new(data, primary_key)
+  b$compact_seq = compact_seq
+
   return(b)
 }
