@@ -1,8 +1,5 @@
 #' @title Resampling Class
 #'
-#' @usage NULL
-#' @format [R6::R6Class] object.
-#'
 #' @description
 #' This is the abstract base class for resampling objects like [ResamplingCV] and [ResamplingBootstrap].
 #'
@@ -12,68 +9,13 @@
 #' Resampling objects can be instantiated on a [Task], which applies the strategy on the task and manifests in a
 #' fixed partition of `row_ids` of the [Task].
 #'
-#' Predefined resamplings are stored in the [mlr3misc::Dictionary] [mlr_resamplings],
+#' Predefined resamplings are stored in the [dictionary][mlr3misc::Dictionary] [mlr_resamplings],
 #' e.g. [`cv`][mlr_resamplings_cv] or [`bootstrap`][mlr_resamplings_bootstrap].
 #'
-#' @section Construction:
-#' Note: This object is typically constructed via a derived classes, e.g. [ResamplingCV] or [ResamplingHoldout].
-#' ```
-#' r = Resampling$new(id, param_set, duplicated_ids = FALSE, man = NA_character_)
-#' ```
 #'
-#' * `id` :: `character(1)`\cr
-#'   Identifier for the resampling strategy.
-#'
-#' * `param_set` :: [paradox::ParamSet]\cr
-#'   Set of hyperparameters.
-#'
-#' * `duplicated_ids` :: `logical(1)`\cr
-#'   Set to `TRUE` if this resampling strategy may have duplicated row ids in a single training set or test set.
-#'
-#' * `man` :: `character(1)`\cr
-#'   String in the format `[pkg]::[topic]` pointing to a manual page for this object.
-#'
-#' @section Fields:
-#' All variables passed to the constructor, and additionally:
-#'
-#' * `iters` :: `integer(1)`\cr
-#'   Return the number of resampling iterations, depending on the values stored in the `param_set`.
-#'
-#' * `instance` :: `any`\cr
-#'   During `instantiate()`, the instance is stored in this slot.
-#'   The instance can be in any arbitrary format.
-#'
-#' * `is_instantiated` :: `logical(1)`\cr
-#'   Is `TRUE`, if the resampling has been instantiated.
-#'
-#' * `task_hash` :: `character(1)`\cr
-#'   The hash of the [Task] which was passed to `r$instantiate()`.
-#'
-#' * `task_nrow` :: `integer(1)`\cr
-#'   The number of observations of the [Task] which was passed to `r$instantiate()`.
-#'
-#' * `hash` :: `character(1)`\cr
-#'   Hash (unique identifier) for this object.
-#'
-#'   E.g., this is `TRUE` for Bootstrap, and `FALSE` for cross validation.
-#'   Only used internally.
-#'
-#' @section Methods:
-#' * `instantiate(task)`\cr
-#'   [Task] -> `self`\cr
-#'   Materializes fixed training and test splits for a given task and stores them in `r$instance`.
-#'
-#' * `train_set(i)`\cr
-#'   `integer(1)` -> (`integer()` | `character()`)\cr
-#'   Returns the row ids of the i-th training set.
-#'
-#' * `test_set(i)`\cr
-#'   `integer(1)` -> (`integer()` | `character()`)\cr
-#'   Returns the row ids of the i-th test set.
-#'
-#' * `help()`\cr
-#'   () -> `NULL`\cr
-#'   Opens the corresponding help page referenced by `$man`.
+#' @template param_id
+#' @template param_param_set
+#' @template param_man
 #'
 #' @section Stratification:
 #' All derived classes support stratified sampling.
@@ -101,6 +43,7 @@
 #' Next, the grouping information is replaced with the respective row ids to generate training and test sets.
 #' The sets can be accessed via `$train_set(i)` and `$test_set(i)`, respectively.
 #'
+#'
 #' @family Resampling
 #' @template seealso_resampling
 #' @export
@@ -137,14 +80,41 @@
 #' prop.table(table(task$truth(r$train_set(1)))) # roughly same proportion
 Resampling = R6Class("Resampling",
   public = list(
+    #' @template field_id
     id = NULL,
+
+    #' @template field_param_set
     param_set = NULL,
+
+    #' @field instance (`any`)\cr
+    #'   During `instantiate()`, the instance is stored in this slot in an arbitrary format.
     instance = NULL,
+
+    #' @field task_hash (`character(1)`)\cr
+    #'   The hash of the [Task] which was passed to `r$instantiate()`.
     task_hash = NA_character_,
+
+    #' @field task_nrow (`integer(1)`)\cr
+    #'   The number of observations of the [Task] which was passed to `r$instantiate()`.
+    #'
     task_nrow = NA_integer_,
+
+    #' @field duplicated_ids (`logical(1)`)\cr
+    #'   If `TRUE`, duplicated rows can occur within a single training set or within a single test set.
+    #'   E.g., this is `TRUE` for Bootstrap, and `FALSE` for cross validation.
+    #'   Only used internally.
     duplicated_ids = NULL,
+
+    #' @template field_man
     man = NULL,
 
+    #' @description
+    #' Creates a new instance of this [R6][R6::R6Class] class.
+    #'
+    #' @param duplicated_ids (`logical(1)`)\cr
+    #'   Set to `TRUE` if this resampling strategy may have duplicated row ids in a single training set or test set.
+    #'
+    #' Note that this object is typically constructed via a derived classes, e.g. [ResamplingCV] or [ResamplingHoldout].
     initialize = function(id, param_set = ParamSet$new(), duplicated_ids = FALSE, man = NA_character_) {
       self$id = assert_string(id, min.chars = 1L)
       self$param_set = assert_param_set(param_set)
@@ -152,10 +122,15 @@ Resampling = R6Class("Resampling",
       self$man = assert_string(man, na.ok = TRUE)
     },
 
+    #' @description
+    #' Helper for print outputs.
     format = function() {
       sprintf("<%s>", class(self)[1L])
     },
 
+    #' @description
+    #' Printer.
+    #' @param ... (ignored).
     print = function(...) {
       pv = self$param_set$values
       catf("%s with %i iterations", format(self), self$iters)
@@ -163,6 +138,23 @@ Resampling = R6Class("Resampling",
       catf(str_indent("* Parameters:", as_short_string(pv, 1000L)))
     },
 
+    #' @description
+    #' Opens the corresponding help page referenced by field `$man`.
+    help = function() {
+      open_help(self$man)
+    },
+
+    #' @description
+    #' Materializes fixed training and test splits for a given task and stores them in `r$instance`
+    #' in an arbitrary format.
+    #'
+    #' @param task ([Task])\cr
+    #'   Task used for instantiation.
+    #'
+    #' @return
+    #' Returns the object itself, but modified **by reference**.
+    #' You need to explicitly `$clone()` the object beforehand if you want to keeps
+    #' the object in its previous state.
     instantiate = function(task) {
       task = assert_task(as_task(task))
       strata = task$strata
@@ -188,21 +180,38 @@ Resampling = R6Class("Resampling",
       invisible(self)
     },
 
+    #' @description
+    #' Returns the row ids of the i-th training set.
+    #'
+    #' @param i (`integer(1)`)\cr
+    #'   Iteration.
+    #' @return (`integer()`) of row ids.
     train_set = function(i) {
       private$.get_set(private$.get_train, i)
     },
 
+    #' @description
+    #' Returns the row ids of the i-th test set.
+    #'
+    #' @param i (`integer(1)`)\cr
+    #'   Iteration.
+    #' @return (`integer()`) of row ids.
     test_set = function(i) {
       private$.get_set(private$.get_test, i)
     }
   ),
 
   active = list(
-    is_instantiated = function() {
+    #' @field is_instantiated (`logical(1)`)\cr
+    #'   Is `TRUE` if the resampling has been instantiated.
+    is_instantiated = function(rhs) {
+      assert_ro_binding(rhs)
       !is.null(self$instance)
     },
 
-    hash = function() {
+    #' @template field_hash
+    hash = function(rhs) {
+      assert_ro_binding(rhs)
       hash(list(class(self), self$id, self$param_set$values, self$instance))
     }
   ),
