@@ -1,7 +1,7 @@
 context("mlr_learners_regr_rpart")
 
 test_that("autotest", {
-  learner = mlr_learners$get("regr.rpart")
+  learner = lrn("regr.rpart")
   expect_learner(learner)
   result = run_autotest(learner)
   expect_true(result, info = result$error)
@@ -9,7 +9,7 @@ test_that("autotest", {
 
 test_that("variable importance", {
   task = TaskRegr$new("foo", as_data_backend(cbind(iris, data.frame(unimportant = runif(150)))), target = "Sepal.Length")
-  learner = mlr_learners$get("regr.rpart")
+  learner = lrn("regr.rpart")
   learner$train(task)
   imp = learner$importance()
   expect_numeric(imp, min.len = 1L, any.missing = FALSE)
@@ -19,8 +19,7 @@ test_that("variable importance", {
 
 test_that("selected_features", {
   task = TaskRegr$new("foo", as_data_backend(cbind(iris, data.frame(unimportant = runif(150)))), target = "Sepal.Length")
-  learner = mlr_learners$get("regr.rpart")
-  learner$param_set$values = insert_named(learner$param_set$values, list(maxdepth = 2))
+  learner = lrn("regr.rpart", maxdepth = 2)
   sf = learner$train(task)$selected_features()
   expect_subset(sf, task$feature_names, empty.ok = FALSE)
 })
