@@ -1,10 +1,12 @@
 context("mlr_resamplings")
 
 test_that("mlr_resamplings", {
+  expect_dictionary(mlr_resamplings, min_items = 1L)
   keys = mlr_resamplings$keys()
-  task = mlr_tasks$get("iris")
+
+  task = tsk("iris")
   for (key in keys) {
-    r = mlr_resamplings$get(key)
+    r = rsmp(key)
     expect_resampling(r) # construction works
     expect_false(r$is_instantiated)
     if (key == "custom") {
@@ -19,7 +21,7 @@ test_that("mlr_resamplings", {
 })
 
 test_that("mlr_resamplings: sugar", {
-  r = mlr_resamplings$get("cv", id = "cv3", param_vals = list(folds = 3L))
+  r = rsmp("cv", id = "cv3", folds = 3L)
   expect_equal(r$id, "cv3")
   expect_equal(r$param_set$values$folds, 3L)
 })
